pub struct TransitionStackItem {
pub cursor: usize,
pub repetition_count: usize,
pub current_node_index: usize,
pub transition_index: usize,
}Expand description
Represents an item in the transition stack of a routine.
The transition stack is similar to a call stack in programming languages.
Note that the cursor and repetition_count should be stored in the stack item
instead of the context because they are specific to the transition being executed and may change during backtracking.
Fields
cursor: usizerepetition_count: usizecurrent_node_index: usizetransition_index: usizeImplementations